[chronojump] RaceAnalyzer do not get port busy on windows after capture and then change mode
- From: Xavier de Blas <xaviblas src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [chronojump] RaceAnalyzer do not get port busy on windows after capture and then change mode
- Date: Fri, 10 Dec 2021 15:06:04 +0000 (UTC)
commit 1204d808ba8393a515164963619487a144370543
Author: Xavier de Blas <xaviblas gmail com>
Date: Fri Dec 10 16:05:00 2021 +0100
RaceAnalyzer do not get port busy on windows after capture and then change mode
src/gui/app1/chronojump.cs | 4 +++-
src/gui/app1/runEncoder.cs | 3 ++-
2 files changed, 5 insertions(+), 2 deletions(-)
---
diff --git a/src/gui/app1/runEncoder.cs b/src/gui/app1/runEncoder.cs
index 756c4cdc8..ec089cbde 100644
--- a/src/gui/app1/runEncoder.cs
+++ b/src/gui/app1/runEncoder.cs
@@ -205,7 +205,8 @@ public partial class ChronoJumpWindow
{
portRE.Close();
portREOpened = false;
- event_execute_label_message.Text = "Disconnected!";
+ //event_execute_label_message.Text = "Disconnected!";
+ LogB.Information("runEncoder portRE Disconnected!");
}
private string runEncoderCheckVersionDo()
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/src/gui/app1/chronojump.cs b/src/gui/app1/chronojump.cs
index 38fc0c7c7..fa691170c 100644
--- a/src/gui/app1/chronojump.cs
+++ b/src/gui/app1/chronojump.cs
@@ -3436,9 +3436,11 @@ public partial class ChronoJumpWindow
setApp1Title(tempSessionName, current_mode);
//maybe we have the force sensor port opened, close it:
if(portFSOpened)
forceSensorDisconnect();
+ if(portREOpened)
+ runEncoderDisconnect();
//if(photocellWirelessCapture != null && photocellWirelessCapture.PortOpened)
if(photocellWirelessCapture != null && ArduinoCapture.PortOpened)
@@ -3436,9 +3436,11 @@ public partial class ChronoJumpWindow
setApp1Title(tempSessionName, current_mode);
- //maybe we have the force sensor port opened, close it:
+ //maybe we have the force sensor port opened or runEncoder port opened, close it:
if(portFSOpened)
forceSensorDisconnect();